@@ -34,10 +34,10 @@
 @class WOContext;
 @class WOResponse;
 
-@class DOMElement;
-
 @class SOGoUser;
 
+@protocol DOMElement;
+
 /*
   SOGoGCSFolder
   
@@ -78,8 +78,6 @@
 			     forUser: (SOGoUser *) theUser;
 
 /* lower level fetches */
-- (BOOL) nameExistsInFolder: (NSString *) objectName;
-
 - (void) deleteEntriesWithIds: (NSArray *) ids;
 
 - (Class) objectClassForComponentName: (NSString *) componentName;
@@ -102,8 +100,8 @@
 - (void) removeFolderSettings: (NSMutableDictionary *) moduleSettings
                 withReference: (NSString *) reference;
 
-- (BOOL) subscribeUser: (NSString *) subscribingUser
-              reallyDo: (BOOL) reallyDo;
+- (BOOL) subscribeUserOrGroup: (NSString *) theIdentifier
+		     reallyDo: (BOOL) reallyDo;
 - (BOOL) userIsSubscriber: (NSString *) subscribingUser;
 
 - (void) initializeQuickTablesAclsInContext: (WOContext *) localContext;
@@ -118,15 +116,12 @@
 - (void) removeAclsForUsers: (NSArray *) users
             forObjectAtPath: (NSArray *) objectPathArray;
 
-/* advisories */
-- (void) sendFolderAdvisoryTemplate: (NSString *) template;
-
 /* DAV */
 - (NSURL *) publicDavURL;
 - (NSURL *) realDavURL;
 
 - (NSDictionary *) davSQLFieldsTable;
-- (NSDictionary *) parseDAVRequestedProperties: (DOMElement *) propElement;
+- (NSDictionary *) parseDAVRequestedProperties: (id <DOMElement>) propElement;
 
 - (NSString *) davCollectionTag;
 
